@@ -1,11 +1,12 @@
 from django.db import models
 from django.utils import timezone
-from apps.user.models import Platform, BaseInfo
+from xj_user.models import Platform, BaseInfo
 import time
 
 
 class PayMode(models.Model):
     pay_mode = models.CharField(verbose_name='支付方式 ', max_length=128)
+
     # description = models.CharField(verbose_name='描述 ', max_length=128) # sieyoo准备加
 
     class Meta:
@@ -18,9 +19,11 @@ class PayMode(models.Model):
 
 class Currency(models.Model):
     currency = models.CharField(verbose_name='币种 ', max_length=128)
+
     # description = models.CharField(verbose_name='描述 ', max_length=128) # sieyoo准备加
 
     class Meta:
+        db_table = 'finance_currency'
         verbose_name_plural = "6. 财务 - 币种列表"
 
     def __str__(self):
@@ -32,6 +35,7 @@ class SandBox(models.Model):
     sand_box_name = models.CharField(verbose_name='沙盒名称', max_length=128)
 
     class Meta:
+        db_table = 'finance_sandbox'
         verbose_name_plural = "7. 财务 - 沙盒列表"
 
     def __str__(self):
@@ -72,10 +76,12 @@ def make_crc16(self):
 
 
 class Transact(models.Model):
-    account = models.ForeignKey(verbose_name='账户', to=BaseInfo, related_name='account_set',
-                                on_delete=models.DO_NOTHING)
-    their_account = models.ForeignKey(verbose_name='对方账户', to=BaseInfo, related_name='their_account_set',
-                                      on_delete=models.DO_NOTHING, )
+    account = models.ForeignKey(verbose_name='账户', to=BaseInfo, db_column='account_id', related_name='account_set',
+                                on_delete=models.DO_NOTHING, db_constraint=False)
+    their_account = models.ForeignKey(verbose_name='对方账户', to=BaseInfo, db_column='their_account_id',
+                                      related_name='their_account_set',
+                                      on_delete=models.DO_NOTHING, db_constraint=False)
+
     # 如何获取用户???
     # year_timestamp函数+hash算法
     hex_code = make_crc16('admin')
@@ -83,34 +89,37 @@ class Transact(models.Model):
     zero_code = '0' + str(decimal_code)
     create_transact_id = year_timestamp() + zero_code
 
-    transact_id = models.BigIntegerField(verbose_name='交易号', unique=True, db_index=True, default=create_transact_id) # 应为transact号
-    transact_time = models.DateTimeField(verbose_name='交易时间', default=timezone.now)
-
-    platform = models.ForeignKey(verbose_name='平台', to=Platform, on_delete=models.DO_NOTHING, default='')
-
-    create_platform_order_id = year_timestamp() + zero_code
-    platform_order_id = models.BigIntegerField(verbose_name='平台订单号', db_index=True, default=create_platform_order_id)
+    # transact_id = models.BigIntegerField(verbose_name='交易号', unique=True, db_index=True, default=create_transact_id) # 应为transact号
+    transact_id = models.CharField(verbose_name='交易号', unique=True, max_length=255, blank=True, db_index=True)
+    enroll_id = models.BigIntegerField(verbose_name='交易号', unique=True, db_index=True)  # 应为transact号
+    # transact_id = models.BigIntegerField(verbose_name='交易号', unique=True, db_index=True, default='') # 应为transact号
+    transact_time = models.DateTimeField(verbose_name='交易时间', auto_now_add=True)
+    # platform = models.ForeignKey(verbose_name='平台', to=Platform, db_column='platform_id', on_delete=models.DO_NOTHING, default='')
+    platform_id = models.IntegerField(verbose_name='平台', default='')
+    # platform_order_id = models.BigIntegerField(verbose_name='平台订单号', db_index=True, default=year_timestamp() + zero_code)
+    order_no = models.CharField(verbose_name='平台订单号', db_index=True, max_length=255, blank=True)
     opposite_account = models.CharField(verbose_name='对方科目', max_length=255, blank=True, null=True, db_index=True)
     summary = models.CharField(verbose_name='摘要说明', max_length=255, blank=True, null=True)
-    currency = models.ForeignKey(verbose_name='币种', to=Currency, on_delete=models.DO_NOTHING, default=1)
-    income = models.DecimalField(verbose_name='收入', max_digits=32, decimal_places=8, blank=True, null=True, db_index=True)
-    outgo = models.DecimalField(verbose_name='支出', max_digits=32, decimal_places=8, blank=True, null=True, db_index=True)
-
-    # 如何获取当前输入的transact_time???
-    the_transact_time = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())
-    print(">>> the_transact_time", the_transact_time)
-    # search_balance = BaseInfo.objects.filter(transact_time=the_transact_time).values('balance').first()
-    # print(">>> search_balance", search_balance)
+    currency = models.ForeignKey(verbose_name='币种', to=Currency, db_column='currency_id', related_name='+',
+                                 on_delete=models.DO_NOTHING, default=1, unique=False, blank=True, null=True,
+                                 help_text='')
+    income = models.DecimalField(verbose_name='收入', max_digits=32, decimal_places=8, blank=True, null=True,
+                                 db_index=True)
+    outgo = models.DecimalField(verbose_name='支出', max_digits=32, decimal_places=8, blank=True, null=True,
+                                db_index=True)
     balance = models.DecimalField(verbose_name='余额', max_digits=32, decimal_places=8, db_index=True, default=0)
-    pay_mode = models.ForeignKey(verbose_name='支付方式', to=PayMode, on_delete=models.DO_NOTHING, default=5)
+    pay_mode = models.ForeignKey(verbose_name='支付方式', to=PayMode, db_column='pay_mode_id', on_delete=models.DO_NOTHING,
+                                 unique=False, blank=True, null=True, default=5)
     goods_info = models.JSONField(verbose_name='商品信息', blank=True, null=True)
     pay_info = models.JSONField(verbose_name='付款信息', blank=True, null=True)
     remark = models.TextField(verbose_name='备注', blank=True, null=True)
-    images = models.CharField(verbose_name='多图上传', blank=True, null=True, max_length=21260)
-    sand_box = models.ForeignKey(verbose_name='沙盒', to=SandBox, db_column='sand_box_id', related_name='+', on_delete=models.DO_NOTHING, blank=True, null=True, db_index=True)
+    images = models.CharField(verbose_name='多图上传', blank=True, null=True, max_length=1000)
+    sand_box = models.ForeignKey(verbose_name='沙盒', to=SandBox, db_column='sand_box_id', related_name='+',
+                                 on_delete=models.DO_NOTHING, unique=False, blank=True, null=True, db_index=True)
     is_reverse = models.BooleanField(verbose_name='是否红冲', max_length=255, blank=True, null=True)
 
     class Meta:
+        db_table = 'finance_transact'
         verbose_name_plural = "1. 财务 - 交易明细"
 
     # 起作用 https://docs.djangoproject.com/zh-hans/3.2/ref/contrib/admin/#django.contrib.admin.ModelAdmin.list_display
@@ -122,8 +131,3 @@ class Transact(models.Model):
     # “反向” 关联
     # 若模型有ForeignKey，外键关联的模型实例将能访问Manager，后者会返回第一个模型的所有实例。默认情况下，该Manager名为FOO_set， FOO即源模型名的小写形式。 Manager返回QuerySets，后者能以 “检索对象” 章节介绍的方式进行筛选和操作。
     # 你可以在定义ForeignKey时设置related_name参数重写这个FOO_set名。例如，若修改Entry模型为blog = ForeignKey(Blog, on_delete=models.CASCADE, related_name='entries')，前文示例代码会看起来像这样:
-
-
-
-
-
