@@ -150,9 +150,10 @@ class FinanceTransactsService:
 
         page = int(params['page']) - 1 if 'page' in params else 0
         size = int(params['size']) if 'size' in params else 10
-        current_page_set = transacts[page * size: page * size + size] if page >= 0 and size > 0 else transacts
 
-        total = current_page_set.count()
+        total = transacts.count()
+
+        current_page_set = transacts[page * size: page * size + size] if page >= 0 and size > 0 else transacts
 
         serializer = FinanceTransactsSerializer(current_page_set, many=True)
 
@@ -164,7 +165,10 @@ class FinanceTransactsService:
             res_list.append(it)
 
         # return {'total': total, 'list': res_list, 'statistics': statistic_list}, None
-        return {'total': total, 'list': res_list}, None
+
+        return {'size': int(size), 'page': int(page+1), 'total': total, 'list': res_list}, None
+
+        # return {'total': total, 'list': res_list}, None
         # 翻译
         # output = _("Welcome to my site.")
 
